Changelog
=========

0.15.0 (2015-01-12)
-------------------

 - #18: Rename ``Interpreter.send`` to ``Interpreter.queue``.
 - Rename ``evaluator`` module to ``code``.

0.14.3 (2015-01-12)
-------------------

 - Add a changelog.
 - Include many additional files in package manifest.
